@@ -34,6 +34,7 @@
 #include "chuck_errmsg.h"
 #include <stdlib.h>
 #include <stdio.h>
+#include <string> // 1.5.1.5 for string concat
 
 
 // 1.5.0.5 (ge) option to include in case we need something from flex/bison
@@ -606,24 +607,24 @@ a_Exp new_exp_from_if( a_Exp cond, a_Exp if_exp, a_Exp else_exp, uint32_t lineNu
     return a;
 }
 
-a_Exp new_exp_decl_external( a_Type_Decl type, a_Var_Decl_List var_decl_list, int is_static, uint32_t lineNum, uint32_t posNum )
+a_Exp new_exp_decl_external( a_Type_Decl type, a_Var_Decl_List var_decl_list, int is_static, int is_const, uint32_t lineNum, uint32_t posNum )
 {
-    a_Exp a = new_exp_decl( type, var_decl_list, is_static, lineNum, posNum );
+    a_Exp a = new_exp_decl( type, var_decl_list, is_static, is_const, lineNum, posNum );
     a->decl.is_global = 1;
     EM_error2( posNum, "'external' keyword is deprecated. please use 'global'" );
 
     return a;
 }
 
-a_Exp new_exp_decl_global( a_Type_Decl type, a_Var_Decl_List var_decl_list, int is_static, uint32_t lineNum, uint32_t posNum )
+a_Exp new_exp_decl_global( a_Type_Decl type, a_Var_Decl_List var_decl_list, int is_static, int is_const, uint32_t lineNum, uint32_t posNum )
 {
-    a_Exp a = new_exp_decl( type, var_decl_list, is_static, lineNum, posNum );
+    a_Exp a = new_exp_decl( type, var_decl_list, is_static, is_const, lineNum, posNum );
     a->decl.is_global = 1;
 
     return a;
 }
 
-a_Exp new_exp_decl( a_Type_Decl type, a_Var_Decl_List var_decl_list, int is_static, uint32_t lineNum, uint32_t posNum )
+a_Exp new_exp_decl( a_Type_Decl type, a_Var_Decl_List var_decl_list, int is_static, int is_const, uint32_t lineNum, uint32_t posNum )
 {
     a_Exp a = (a_Exp)checked_malloc( sizeof( struct a_Exp_ ) );
     a->s_type = ae_exp_decl;
@@ -632,6 +633,7 @@ a_Exp new_exp_decl( a_Type_Decl type, a_Var_Decl_List var_decl_list, int is_stat
     a->decl.var_decl_list = var_decl_list;
     a->line = lineNum; a->where = posNum;
     a->decl.is_static = is_static;
+    a->decl.is_const = is_const; // 1.5.1.3
     a->decl.line = lineNum; a->decl.where = posNum;
     a->decl.self = a;
 
@@ -799,6 +801,32 @@ a_Func_Def new_func_def( ae_Keyword func_decl, ae_Keyword static_decl,
     return a;
 }
 
+// @operator overload | 1.5.1.5
+a_Func_Def new_op_overload( ae_Keyword func_decl, ae_Keyword static_decl,
+                            a_Type_Decl type_decl, ae_Operator oper,
+                            a_Arg_List arg_list, a_Stmt code,
+                            uint32_t is_from_ast, uint32_t overload_post,
+                            uint32_t lineNum, uint32_t posNum, uint32_t operPos )
+{
+    a_Func_Def a = (a_Func_Def)checked_malloc(
+        sizeof( struct a_Func_Def_ ) );
+    a->func_decl = func_decl;
+    a->static_decl = static_decl;
+    a->type_decl = type_decl;
+    // construct op overload function name
+    std::string s( "@operator" ); s += op2str(oper);
+    a->name = insert_symbol( s.c_str() );
+    a->op2overload = oper;
+    a->arg_list = arg_list;
+    a->s_type = ae_func_user;
+    a->code = code;
+    a->ast_owned = is_from_ast != 0; // 1.5.0.5 (ge) added
+    a->overload_post = overload_post; // 1.5.1.5 (ge) added
+    a->line = lineNum; a->where = posNum; a->operWhere = operPos;
+
+    return a;
+}
+
 a_Class_Def new_class_def( ae_Keyword class_decl, a_Id_List name,
                            a_Class_Ext ext, a_Class_Body body, uint32_t lineNum, uint32_t posNum )
 {
@@ -944,6 +972,7 @@ a_Complex new_complex( a_Exp re, uint32_t lineNum, uint32_t posNum )
 {
     a_Complex a = (a_Complex)checked_malloc( sizeof( struct a_Complex_ ) );
     a->re = re;
+    // NOTE: if this ever changes, make sure to also update delete_complex | 1.5.1.0
     if( re ) a->im = re->next;
     a->line = lineNum; a->where = posNum;
 
@@ -954,6 +983,7 @@ a_Polar new_polar( a_Exp mod, uint32_t lineNum, uint32_t posNum )
 {
     a_Polar a = (a_Polar)checked_malloc( sizeof( struct a_Polar_ ) );
     a->mod = mod;
+    // NOTE: if this ever changes, make sure to also update delete_polar | 1.5.1.0
     if( mod ) a->phase = mod->next;
     a->line = lineNum; a->where = posNum;
 
@@ -976,6 +1006,7 @@ a_Vec new_vec( a_Exp e, uint32_t lineNum, uint32_t posNum ) // ge: added 1.3.5.3
 
 
 static const char * op_str[] = {
+  "[no_op]",
   "+",
   "-",
   "*",
@@ -1005,24 +1036,40 @@ static const char * op_str[] = {
   ">>=>",
   "<<=>",
   "%=>",
-  "->",
   "++",
   "--",
   "~",
   "!",
   "@=>",
   "=<",
+  "^=>",
+  "=",
+  "$",
+  "@@",
+  "::",
   "spork ~",
   "typeof",
   "sizeof",
-  "new"
+  "new",
+  "<-",
+  "->",
+  "<--",
+  "-->",
+  ">--",
+  "--<"
 };
 
 
+
+
+//-----------------------------------------------------------------------------
+// name: op2str()
+// desc: operator enumeration to string
+//-----------------------------------------------------------------------------
 const char * op2str( ae_Operator op )
 {
     t_CKINT index = (t_CKINT)op;
-    if( index < 0 || index >= (t_CKINT)(sizeof( op_str )/sizeof( char * )) )
+    if( index < 0 || index >= ae_op_count )
         return "[non-existent operator]";
 
     return op_str[index];
@@ -1031,6 +1078,23 @@ const char * op2str( ae_Operator op )
 
 
 
+//-----------------------------------------------------------------------------
+// name: str2op()
+// desc: string to operator enumeration
+//-----------------------------------------------------------------------------
+ae_Operator str2op( const char * str )
+{
+    std::string s(str);
+
+    for( t_CKUINT i = 1; i < ae_op_count; i++ )
+        if( s == op_str[i] ) return (ae_Operator)i;
+
+    return ae_op_none;
+}
+
+
+
+
 //-----------------------------------------------------------------------------
 // AST cleanup function (these are mostly called by chuck compiler)
 //-----------------------------------------------------------------------------
@@ -1388,7 +1452,6 @@ void delete_exp_contents( a_Exp e )
     }
 }
 
-
 // delete an exp
 void delete_exp( a_Exp e )
 {
@@ -1529,16 +1592,14 @@ void delete_exp_from_complex( a_Exp_Primary e )
 {
     EM_log( CK_LOG_FINEST, "deleting exp (primary complex) [%p]...", (void *)e );
 
-    delete_exp( e->complex->re );
-    delete_exp( e->complex->im );
+    delete_complex( e->complex );
 }
 
 void delete_exp_from_polar( a_Exp_Primary e )
 {
     EM_log( CK_LOG_FINEST, "deleting exp (primary polar) [%p]...", (void *)e );
 
-    delete_exp( e->polar->mod );
-    delete_exp( e->polar->phase );
+    delete_polar( e->polar );
 }
 
 void delete_exp_from_vec( a_Exp_Primary e )
@@ -1609,7 +1670,8 @@ void delete_complex( a_Complex c )
 {
     EM_log( CK_LOG_FINEST, "deleting complex [%p]...", (void *)c );
     delete_exp( c->re );
-    delete_exp( c->im );
+    // do not delete c->im, since it's just c->re->next
+    // delete_exp( c->im );
     CK_SAFE_FREE( c );
 }
 
@@ -1617,7 +1679,8 @@ void delete_polar( a_Polar p )
 {
     EM_log( CK_LOG_FINEST, "deleting polar [%p]...", (void *)p );
     delete_exp( p->mod );
-    delete_exp( p->phase );
+    // do not delete p->phase, since it's just c->re->next
+    // delete_exp( p->phase );
     CK_SAFE_FREE( p );
 }
 
