@@ -84,6 +84,7 @@ typedef struct { t_CKFLOAT re ; t_CKFLOAT im ; } t_CKCOMPLEX;
 typedef struct { t_CKFLOAT modulus ; t_CKFLOAT phase ; } t_CKPOLAR;
 
 // vector types
+typedef struct { t_CKFLOAT x ; t_CKFLOAT y ; } t_CKVEC2;
 typedef struct { t_CKFLOAT x ; t_CKFLOAT y ; t_CKFLOAT z ; } t_CKVEC3;
 typedef struct { t_CKFLOAT x ; t_CKFLOAT y ; t_CKFLOAT z ; t_CKFLOAT w ; } t_CKVEC4;
 typedef struct { t_CKUINT N ; t_CKFLOAT * values ; } t_CKVECTOR;
@@ -101,6 +102,7 @@ typedef struct { t_CKUINT N ; t_CKFLOAT * values ; } t_CKVECTOR;
 #define sz_VOIDPTR                  sizeof(t_CKVOIDPTR)
 #define sz_COMPLEX                  sizeof(t_CKCOMPLEX)
 #define sz_POLAR                    sizeof(t_CKPOLAR)
+#define sz_VEC2                     sizeof(t_CKVEC2)
 #define sz_VEC3                     sizeof(t_CKVEC3)
 #define sz_VEC4                     sizeof(t_CKVEC4)
 #define sz_VECTOR                   sizeof(t_CKVECTOR)
@@ -112,11 +114,11 @@ typedef struct { t_CKUINT N ; t_CKFLOAT * values ; } t_CKVECTOR;
 enum te_KindOf
 {
     kindof_VOID = 0,
-    kindof_INT = 1,
-    kindof_FLOAT = 2,
-    kindof_COMPLEX = 3,
-    kindof_VEC3 = 4,
-    kindof_VEC4 = 5
+    kindof_INT,
+    kindof_FLOAT,
+    kindof_VEC2, // 1.5.1.7 (ge) was kindof_COMPLEX
+    kindof_VEC3,
+    kindof_VEC4
 };
 
 typedef char *                      c_str;
@@ -169,6 +171,7 @@ typedef struct { SAMPLE re ; SAMPLE im ; } t_CKCOMPLEX_SAMPLE;
 #define CK_SAFE_REF_ASSIGN(lhs,rhs) do { Chuck_VM_Object * temp = (lhs); (lhs) = (rhs); CK_SAFE_ADD_REF(lhs); CK_SAFE_RELEASE(temp); } while(0)
 #define CK_SAFE_FREE(x)             do { if(x){ free(x); (x) = NULL; } } while(0)
 #define CK_SAFE_UNLOCK_DELETE(x)    do { if(x){ (x)->unlock(); delete (x); (x) = NULL; } } while(0)
+#define CK_SAFE_UNLOCK_RELEASE(x)   do { if(x){ (x)->unlock(); (x)->release(); (x) = NULL; } } while(0)
 
 // max + min
 #define ck_max(x,y)                 ( (x) >= (y) ? (x) : (y) )
