@@ -113,7 +113,7 @@ void Chuck_VM_Object::add_ref()
 
 //-----------------------------------------------------------------------------
 // name: release()
-// desc: remove reference
+// desc: decrement reference; deletes objects when refcount reaches 0;
 //-----------------------------------------------------------------------------
 void Chuck_VM_Object::release()
 {
@@ -122,10 +122,10 @@ void Chuck_VM_Object::release()
     //-----------------------------------------------------------------------------
     if( m_ref_count <= 0 )
     {
-        // print warning
+        // log warning
         EM_log( CK_LOG_FINEST, "(internal) Object.release() refcount already %d", m_ref_count );
 
-        // print error
+        // disabled: error out
         // EM_error3( "[chuck]: (internal error) Object.release() refcount == %d", m_ref_count );
         // make sure there is at least one reference
         // assert( m_ref_count > 0 );
@@ -136,8 +136,6 @@ void Chuck_VM_Object::release()
         m_ref_count--;
     }
 
-    // added 1.3.0.0
-    // CK_VM_DEBUG(CK_FPRINTF_STDERR( "Chuck_VM_Object::release() : 0x%08x, %s, %ulu\n", this, mini_type(typeid(*this).name()), m_ref_count));
     // updated 1.5.0.5 to use Chuck_VM_Debug
     CK_VM_DEBUGGER( release( this ) );
 
@@ -148,10 +146,10 @@ void Chuck_VM_Object::release()
         if( our_locks_in_effect && m_locked )
         {
             EM_error2( 0, "(internal error) releasing locked VM object!" );
-            // fail
+            // bail out
             assert( FALSE );
             // in case assert is disabled
-            *(int *)0 = 1;
+            // *(int *)0 = 1;
         }
 
     #ifndef __CHUNREAL_ENGINE__
@@ -165,8 +163,9 @@ void Chuck_VM_Object::release()
         // track | 1.5.0.5 (ge)
         CK_VM_DEBUGGER( destruct( this ) );
 
-        // REFACTOR-2017: doing this for now
-        delete this;
+        // trigger this object's deletion / destructors
+        // should be valid as long as no members are used beyond this point
+        delete this; // REFACTOR-2017
     }
 }
 
@@ -266,36 +265,50 @@ Chuck_Object::Chuck_Object()
 
 
 //-----------------------------------------------------------------------------
-// name: Chuck_Object()
-// desc: ...
+// name: ~Chuck_Object()
+// desc: chuck object internal destructor
 //-----------------------------------------------------------------------------
 Chuck_Object::~Chuck_Object()
 {
-    // added 1.3.0.0:
-    // call destructors, from latest descended child to oldest parent
+    // get this object's type
     Chuck_Type * type = this->type_ref;
+
+    // shred
+    Chuck_VM_Shred * shred = NULL;
+    // a way to check if we are in run state or post-run (shutdown) state | 1.5.1.8
+    // NOTE important to look at carrier->vm directly, and not a copy of vm pointer
+    Chuck_VM * vm = type && type->env() && type->env()->carrier() ? type->env()->carrier()->vm : NULL;
+    // if we are in normal run state
+    if( vm ) {
+        // update shred ref from origin shred  | 1.5.1.8
+        shred = origin_shred ? origin_shred : vm->get_current_shred();
+    }
+
+    // call destructors, from latest descended child to oldest parent | 1.3.0.0
     while( type != NULL )
     {
         // SPENCER TODO: HACK! is there a better way to call the dtor?
         if( type->info && type->has_destructor ) // 1.5.0.0 (ge) added type->info check
         {
-            // sanity check
+            // verify: for now, can only be native func
             assert( type->info->dtor && type->info->dtor->native_func );
-            // REFACTOR-2017: do we know which VM to pass in? (currently NULL)
-            ((f_dtor)(type->info->dtor->native_func))( this, NULL, NULL, Chuck_DL_Api::instance() );
+            // REFACTOR-2017: do we know which VM to pass in? (diff main/sub instance?)
+            // pass in type-associated vm and current shred | 1.5.1.8
+            ((f_dtor)(type->info->dtor->native_func))( this, vm, shred, Chuck_DL_Api::instance() );
         }
-
         // go up the inheritance
         type = type->parent;
     }
 
     // release
     CK_SAFE_RELEASE( origin_shred );
-    CK_SAFE_RELEASE( origin_vm );
+    CK_SAFE_RELEASE( type_ref );
+    // CK_SAFE_RELEASE( origin_vm );
+    // just zero out | 1.5.1.8 (ge)
+    origin_vm = NULL;
 
     // free
     CK_SAFE_DELETE( vtable );
-    CK_SAFE_RELEASE( type_ref );
     CK_SAFE_DELETE_ARRAY( data );
 }
 
@@ -349,12 +362,14 @@ void Chuck_Object::setOriginShred( Chuck_VM_Shred * shred )
 
 //-----------------------------------------------------------------------------
 // name: setOriginVM()
-// desc: set origin shred
+// desc: set origin VM
 //-----------------------------------------------------------------------------
 void Chuck_Object::setOriginVM( Chuck_VM * vm )
 {
-    // assign
-    CK_SAFE_REF_ASSIGN( this->origin_vm, vm );
+    // copy only; avoid refcounting VM on a per-object basis | 1.5.1.8
+    this->origin_vm = vm;
+    // reference count assign
+    // CK_SAFE_REF_ASSIGN( this->origin_vm, vm );
 }
 
 
@@ -1510,7 +1525,7 @@ t_CKUINT Chuck_Array16::addr( const string & key )
 // name: get()
 // desc: ...
 //-----------------------------------------------------------------------------
-t_CKINT Chuck_Array16::get( t_CKINT i, t_CKCOMPLEX * val )
+t_CKINT Chuck_Array16::get( t_CKINT i, t_CKVEC2 * val )
 {
     // bound check
     if( i < 0 || i >= m_vector.capacity() )
@@ -1522,6 +1537,9 @@ t_CKINT Chuck_Array16::get( t_CKINT i, t_CKCOMPLEX * val )
     // return good
     return 1;
 }
+// redirect as vec2
+t_CKINT Chuck_Array16::get( t_CKINT i, t_CKCOMPLEX * val )
+{ return this->get( i, (t_CKVEC2 *)val ); }
 
 
 
@@ -1530,14 +1548,14 @@ t_CKINT Chuck_Array16::get( t_CKINT i, t_CKCOMPLEX * val )
 // name: get()
 // desc: ...
 //-----------------------------------------------------------------------------
-t_CKINT Chuck_Array16::get( const string & key, t_CKCOMPLEX * val )
+t_CKINT Chuck_Array16::get( const string & key, t_CKVEC2 * val )
 {
     // set to zero
-    val->re = 0.0;
-    val->im = 0.0;
+    val->x = 0;
+    val->y = 0;
 
     // iterator
-    map<string, t_CKCOMPLEX>::iterator iter = m_map.find( key );
+    map<string, t_CKVEC2>::iterator iter = m_map.find( key );
 
     // check
     if( iter != m_map.end() )
@@ -1549,6 +1567,9 @@ t_CKINT Chuck_Array16::get( const string & key, t_CKCOMPLEX * val )
     // return good
     return 1;
 }
+// redirect as vec2
+t_CKINT Chuck_Array16::get( const string & key, t_CKCOMPLEX * val )
+{ return this->get( key, (t_CKVEC2 *)val ); }
 
 
 
@@ -1557,7 +1578,7 @@ t_CKINT Chuck_Array16::get( const string & key, t_CKCOMPLEX * val )
 // name: set()
 // desc: ...
 //-----------------------------------------------------------------------------
-t_CKINT Chuck_Array16::set( t_CKINT i, const t_CKCOMPLEX & val )
+t_CKINT Chuck_Array16::set( t_CKINT i, const t_CKVEC2 & val )
 {
     // bound check
     if( i < 0 || i >= m_vector.capacity() )
@@ -1569,6 +1590,9 @@ t_CKINT Chuck_Array16::set( t_CKINT i, const t_CKCOMPLEX & val )
     // return good
     return 1;
 }
+// redirect as vec2
+t_CKINT Chuck_Array16::set( t_CKINT i, const t_CKCOMPLEX & val )
+{ return this->set( i, (t_CKVEC2 &)val ); }
 
 
 
@@ -1577,10 +1601,10 @@ t_CKINT Chuck_Array16::set( t_CKINT i, const t_CKCOMPLEX & val )
 // name: set()
 // desc: ...
 //-----------------------------------------------------------------------------
-t_CKINT Chuck_Array16::set( const string & key, const t_CKCOMPLEX & val )
+t_CKINT Chuck_Array16::set( const string & key, const t_CKVEC2 & val )
 {
     // 1.3.1.1: removed this
-    // map<string, t_CKCOMPLEX>::iterator iter = m_map.find( key );
+    // map<string, t_CKVEC2>::iterator iter = m_map.find( key );
 
     // 1.3.5.3: removed this
     // if( val.re == 0 && val.im == 0 ) m_map.erase( key ); else
@@ -1589,6 +1613,9 @@ t_CKINT Chuck_Array16::set( const string & key, const t_CKCOMPLEX & val )
     // return good
     return 1;
 }
+// redirect as vec2
+t_CKINT Chuck_Array16::set( const string & key, const t_CKCOMPLEX & val )
+{ return this->set( key, (t_CKVEC2 &)val ); }
 
 
 
@@ -1597,7 +1624,7 @@ t_CKINT Chuck_Array16::set( const string & key, const t_CKCOMPLEX & val )
 // name: insert() | 1.5.0.8 (ge) added
 // desc: insert before position | O(n) running time
 //-----------------------------------------------------------------------------
-t_CKINT Chuck_Array16::insert( t_CKINT i, const t_CKCOMPLEX & val )
+t_CKINT Chuck_Array16::insert( t_CKINT i, const t_CKVEC2 & val )
 {
     // bound check
     if( i < 0 || i >= m_vector.capacity() )
@@ -1640,7 +1667,7 @@ t_CKINT Chuck_Array16::map_erase( const string & key )
 // name: push_back()
 // desc: ...
 //-----------------------------------------------------------------------------
-t_CKINT Chuck_Array16::push_back( const t_CKCOMPLEX & val )
+t_CKINT Chuck_Array16::push_back( const t_CKVEC2 & val )
 {
     // add to vector
     m_vector.push_back( val );
@@ -1662,8 +1689,8 @@ t_CKINT Chuck_Array16::pop_back( )
         return 0;
 
     // zero
-    m_vector[m_vector.size()-1].re = 0.0;
-    m_vector[m_vector.size()-1].im = 0.0;
+    m_vector[m_vector.size()-1].x = 0;
+    m_vector[m_vector.size()-1].y = 0;
     // add to vector
     m_vector.pop_back();
 
@@ -1677,7 +1704,7 @@ t_CKINT Chuck_Array16::pop_back( )
 // name: push_front() | 1.5.0.8 (ge) added
 // desc: prepend element by value | O(n) running time
 //-----------------------------------------------------------------------------
-t_CKINT Chuck_Array16::push_front( const t_CKCOMPLEX & val )
+t_CKINT Chuck_Array16::push_front( const t_CKVEC2 & val )
 {
     // add to vector
     m_vector.insert( m_vector.begin(), val );
@@ -1760,7 +1787,7 @@ void Chuck_Array16::get_keys( std::vector<std::string> & keys )
     // clear the return array
     keys.clear();
     // iterator
-    for( std::map<std::string,t_CKCOMPLEX>::iterator iter = m_map.begin(); iter !=m_map.end(); iter++ )
+    for( std::map<std::string,t_CKVEC2>::iterator iter = m_map.begin(); iter !=m_map.end(); iter++ )
     {
         // add to list
         keys.push_back((*iter).first);
@@ -1798,7 +1825,7 @@ void Chuck_Array16::shuffle()
 // name: ck_compare_polar()
 // desc: compare function for sorting chuck polar values
 //-----------------------------------------------------------------------------
-static bool ck_compare_polar( const t_CKCOMPLEX & lhs, const t_CKCOMPLEX & rhs )
+static bool ck_compare_polar( const t_CKVEC2 & lhs, const t_CKVEC2 & rhs )
 {
     // cast to polar
     const t_CKPOLAR * pL = (const t_CKPOLAR *)&lhs;
@@ -1819,6 +1846,29 @@ static bool ck_compare_polar( const t_CKCOMPLEX & lhs, const t_CKCOMPLEX & rhs )
 
 
 
+//-----------------------------------------------------------------------------
+// name: ck_compare_vec2()
+// desc: compare function for sorting chuck vec2 values
+//-----------------------------------------------------------------------------
+static bool ck_compare_vec2( const t_CKVEC2 & lhs, const t_CKVEC2 & rhs )
+{
+    // compare magnitude first
+    t_CKFLOAT x = ck_vec2_magnitude(lhs);
+    t_CKFLOAT y = ck_vec2_magnitude(rhs);
+    // if magnitude equal
+    if( x == y ) {
+        // compare phase
+        t_CKFLOAT xp = ck_vec2_phase(lhs);
+        t_CKFLOAT yp = ck_vec2_phase(rhs);
+        return xp < yp;
+    }
+    // return magnitude comparison
+    return x < y;
+}
+
+
+
+
 //-----------------------------------------------------------------------------
 // name: ck_compare_complex()
 // desc: compare function for sorting chuck complex values
@@ -1856,7 +1906,7 @@ void Chuck_Array16::sort()
     if( m_isPolarType )
         std::sort( m_vector.begin(), m_vector.end(), ck_compare_polar );
     else
-        std::sort( m_vector.begin(), m_vector.end(), ck_compare_complex );
+        std::sort( m_vector.begin(), m_vector.end(), ck_compare_vec2 );
 }
 
 
@@ -1866,7 +1916,7 @@ void Chuck_Array16::sort()
 // name: back()
 // desc: ...
 //-----------------------------------------------------------------------------
-t_CKINT Chuck_Array16::back( t_CKCOMPLEX * val ) const
+t_CKINT Chuck_Array16::back( t_CKVEC2 * val ) const
 {
     // check
     if( m_vector.size() == 0 )
@@ -1961,8 +2011,8 @@ void Chuck_Array16::zero( t_CKUINT start, t_CKUINT end )
     for( t_CKUINT i = start; i < end; i++ )
     {
         // zero
-        m_vector[i].re = 0.0;
-        m_vector[i].im = 0.0;
+        m_vector[i].x = 0;
+        m_vector[i].y = 0;
     }
 }
 
