@@ -36,8 +36,9 @@
 #include "util_hid.h"
 #include "chuck_errmsg.h"
 #include "chuck_vm.h"
+#include "util_platforms.h" // for ck_usleep()
 
-#ifndef __PLATFORM_WIN32__
+#ifndef __PLATFORM_WINDOWS__
 #include <unistd.h>
 #else
 #include "chuck_def.h"
@@ -273,7 +274,7 @@ t_CKBOOL PhyHidDevIn::remove_vm( Chuck_VM * vm )
     }
 
     // delete cbufs[vm] and remove from map
-    SAFE_DELETE( cbufs[vm] );
+    CK_SAFE_DELETE( cbufs[vm] );
     cbufs.erase( vm );
 
     return TRUE;
@@ -293,7 +294,7 @@ t_CKBOOL PhyHidDevIn::close()
         if( cbuf != NULL )
         {
             // delete
-            SAFE_DELETE( cbuf );
+            CK_SAFE_DELETE( cbuf );
             // REFACTOR-2017: copied over this TODO from previous edition:
             // TODO: release references from cbuf
         }
@@ -389,7 +390,7 @@ HidOut::HidOut()
 HidOut::~HidOut()
 {
     if( phout ) this->close();
-    SAFE_DELETE( phout );
+    CK_SAFE_DELETE( phout );
 }
 
 
@@ -470,7 +471,7 @@ HidIn::HidIn()
 HidIn::~HidIn( )
 {
     this->close();
-    // SAFE_DELETE( min );
+    // CK_SAFE_DELETE( min );
 }
 
 
@@ -480,14 +481,14 @@ HidIn::~HidIn( )
 // name: open()
 // desc: open
 //-----------------------------------------------------------------------------
-t_CKBOOL HidIn::open( Chuck_VM * vm, t_CKINT device_type, t_CKINT device_num )
+t_CKBOOL HidIn::open( Chuck_VM * vm, t_CKINT device_type, t_CKINT device_num, t_CKBOOL suppressErrMsg )
 {
     // close if already opened
     if( m_valid )
         this->close();
 
     // open
-    return m_valid = HidInManager::open( this, vm, device_type, device_num );
+    return m_valid = HidInManager::open( this, vm, device_type, device_num, suppressErrMsg );
 }
 
 
@@ -497,14 +498,14 @@ t_CKBOOL HidIn::open( Chuck_VM * vm, t_CKINT device_type, t_CKINT device_num )
 // name: open()
 // desc: open
 //-----------------------------------------------------------------------------
-t_CKBOOL HidIn::open( Chuck_VM * vm, std::string & name, t_CKUINT device_type )
+t_CKBOOL HidIn::open( Chuck_VM * vm, t_CKINT device_type, std::string & name, t_CKBOOL suppressErrMsg )
 {
     // close if already opened
     if( m_valid )
         this->close();
 
     // open
-    return m_valid = HidInManager::open( this, vm, device_type, name );
+    return m_valid = HidInManager::open( this, vm, device_type, name, suppressErrMsg );
 }
 
 
@@ -532,9 +533,9 @@ void HidInManager::init()
         msg_buffer = new CBufferSimple;
         msg_buffer->initialize( 1000, sizeof( HidMsg ) );
 
-#ifndef __MACOSX_CORE__
+#ifndef __PLATFORM_APPLE__
         Hid_init();
-#endif // __MACOSX_CORE__
+#endif
 
         for( size_t j = 0; j < CK_HID_DEV_COUNT; j++ )
         {
@@ -542,7 +543,7 @@ void HidInManager::init()
                 default_drivers[j].init();
         }
 
-#ifdef __MACOSX_CORE__
+#ifdef __PLATFORM_APPLE__
         // start thread
         if( the_thread == NULL )
         {
@@ -622,7 +623,7 @@ void HidInManager::init_default_drivers()
     default_drivers[CK_HID_DEV_MULTITOUCH].driver_name = "multitouch";
 }
 
-void HidInManager::cleanup()
+void HidInManager::cleanup( t_CKUINT msWait )
 {
     // log
     EM_log( CK_LOG_INFO, "shutting down HID..." );
@@ -636,19 +637,23 @@ void HidInManager::cleanup()
             for( vector<PhyHidDevIn *>::size_type j = 0; j < the_matrix[i].size(); j++ )
             {
                 // deallocate devices
-                SAFE_DELETE( the_matrix[i][j] );
+                CK_SAFE_DELETE( the_matrix[i][j] );
             }
         }
 
         // flag
         thread_going = FALSE;
 
+        // wait for thread to wrap up | 1.5.1.3 (ge) added
+        // appears needed to avert sometimes-crash on shutdown
+        if( msWait > 0 ) ck_usleep( msWait * 1000 );
+
         // break Hid_poll();
         Hid_quit();
 
         // clean up
         if( the_thread != NULL )
-            SAFE_DELETE( the_thread );
+            CK_SAFE_DELETE( the_thread );
 
         // clean up subsystems
         for( size_t j = 0; j < CK_HID_DEV_COUNT; j++ )
@@ -660,7 +665,7 @@ void HidInManager::cleanup()
         if( msg_buffer )
         {
             msg_buffer->cleanup();
-            SAFE_DELETE( msg_buffer );
+            CK_SAFE_DELETE( msg_buffer );
         }
 
         for( std::map< Chuck_VM *, CBufferSimple * >::iterator it =
@@ -679,7 +684,7 @@ void HidInManager::cleanup()
 }
 
 
-t_CKBOOL HidInManager::open( HidIn * hin, Chuck_VM * vm, t_CKINT device_type, t_CKINT device_num )
+t_CKBOOL HidInManager::open( HidIn * hin, Chuck_VM * vm, t_CKINT device_type, t_CKINT device_num, t_CKBOOL suppressErrMsg )
 {
     // init?
     if( has_init == FALSE )
@@ -725,9 +730,9 @@ t_CKBOOL HidInManager::open( HidIn * hin, Chuck_VM * vm, t_CKINT device_type, t_
         {
             // log
             // should this use EM_log instead, with a higher log level?
-            EM_error2( 0, "HidIn: couldn't open %s %d...",
+            if( !suppressErrMsg ) EM_error2( 0, "HidIn: couldn't open %s %d...",
                        default_drivers[device_type].driver_name, device_num );
-            SAFE_DELETE( phin );
+            CK_SAFE_DELETE( phin );
             return FALSE;
         }
 
@@ -763,7 +768,7 @@ t_CKBOOL HidInManager::open( HidIn * hin, Chuck_VM * vm, t_CKINT device_type, t_
 
 
 
-t_CKBOOL HidInManager::open( HidIn * hin, Chuck_VM * vm, t_CKINT device_type, std::string & device_name )
+t_CKBOOL HidInManager::open( HidIn * hin, Chuck_VM * vm, t_CKINT device_type, std::string & device_name, t_CKBOOL suppressErrMsg )
 {
     // init?
     if( has_init == FALSE )
@@ -784,9 +789,12 @@ t_CKBOOL HidInManager::open( HidIn * hin, Chuck_VM * vm, t_CKINT device_type, st
         // check type
         if( device_type < 1 || device_type >= CK_HID_DEV_COUNT )
         {
+            // should this use EM_log instead, with a higher log level?
+            if( !suppressErrMsg )
+                EM_error2( 0, "HidInManager: open() failed -> invalid type '%d'...", device_type );
             // log
-            EM_log( CK_LOG_WARNING, "HidInManager: open() failed -> invalid type '%d'...",
-                    device_type );
+            // EM_log( CK_LOG_WARNING, "HidInManager: open() failed -> invalid type '%d'...",
+            //         device_type );
             return FALSE;
         }
 
@@ -825,8 +833,11 @@ t_CKBOOL HidInManager::open( HidIn * hin, Chuck_VM * vm, t_CKINT device_type, st
         }
     }
 
-    EM_log( CK_LOG_WARNING, "HidInManager: open() failed -> no device named '%s'...",
-            device_name.c_str() );
+    // should this use EM_log instead, with a higher log level?
+    if( !suppressErrMsg ) EM_error2( 0, "HidInManager: open() failed -> no device named '%s'...",
+                                    device_name.c_str());
+    // EM_log( CK_LOG_WARNING, "HidInManager: open() failed -> no device named '%s'...",
+    //         device_name.c_str() );
 
     return FALSE;
 }
@@ -993,13 +1004,13 @@ extern "C" void push_message( HidMsg msg )
 // name: cb_hid_input
 // desc: call back
 //-----------------------------------------------------------------------------
-#ifndef __PLATFORM_WIN32__
+#ifndef __PLATFORM_WINDOWS__
 void * HidInManager::cb_hid_input( void * stuff )
 #else
 unsigned __stdcall HidInManager::cb_hid_input( void * stuff )
 #endif
 {
-#ifdef __MACOSX_CORE__
+#ifdef __PLATFORM_APPLE__
     Hid_init();
 #endif
 
@@ -1034,9 +1045,9 @@ void HidInManager::probeHidIn()
         if( count == 0 )
             continue;
 
-        EM_error2b( 0, "------( %s device%s: %i )------",
-                    default_drivers[i].driver_name,
-                    count > 1 ? "s" : "", count );
+        EM_print2blue( "------( %i %s device%s )------",
+                        count, default_drivers[i].driver_name,
+                        count > 1 ? "s" : "" );
 
         for( int j = 0; j < count; j++ )
         {
