@@ -67,6 +67,8 @@ CK_DLL_SFUN( machine_version_impl );
 CK_DLL_SFUN( machine_setloglevel_impl );
 CK_DLL_SFUN( machine_getloglevel_impl );
 CK_DLL_SFUN( machine_refcount_impl);
+CK_DLL_SFUN( machine_regstack_impl);
+CK_DLL_SFUN( machine_memstack_impl);
 CK_DLL_SFUN( machine_opOverloadPush_impl);
 CK_DLL_SFUN( machine_opOverloadPop_impl);
 CK_DLL_SFUN( machine_opOverloadReset_impl);
@@ -264,6 +266,14 @@ DLL_QUERY machine_query( Chuck_DL_Query * QUERY )
     QUERY->add_arg( QUERY, "Object", "obj" );
     QUERY->doc_func( QUERY, "get an object's current internal reference count; this is intended for testing or curiosity; NOTE: this function intentionally does not take into account any reference counting related to the calling of this function (normally all functions increments the reference count for objects passed as arguments and decrements upon returning)" );
 
+    // get reg stack pointer
+    QUERY->add_sfun( QUERY, machine_regstack_impl, "int", "sp_reg" );
+    QUERY->doc_func( QUERY, "get the calling shred's operand (aka \"reg\"/register) stack pointer; intended for either debugging or curiosity." );
+
+    // get mem stack pointer
+    QUERY->add_sfun( QUERY, machine_memstack_impl, "int", "sp_mem" );
+    QUERY->doc_func( QUERY, "get the calling shred's memory (aka \"mem\") stack pointer; intended for either debugging or curiosity." );
+
     // add examples
     QUERY->add_ex( QUERY, "machine/eval.ck" );
     QUERY->add_ex( QUERY, "machine/eval-global.ck" );
@@ -609,6 +619,18 @@ CK_DLL_SFUN( machine_refcount_impl )
     RETURN->v_int = obj != NULL ? obj->m_ref_count-1 : 0;
 }
 
+CK_DLL_SFUN( machine_regstack_impl )
+{
+    // return reg stack pointer
+    RETURN->v_int = (t_CKINT)SHRED->reg->sp;
+}
+
+CK_DLL_SFUN( machine_memstack_impl )
+{
+    // return mem stack pointer
+    RETURN->v_int = (t_CKINT)SHRED->mem->sp;
+}
+
 CK_DLL_SFUN( machine_opOverloadPush_impl)
 {
     VM->env()->op_registry.push();
