@@ -87,9 +87,22 @@ CK_DLL_SFUN( randomf_impl );
 CK_DLL_SFUN( random2f_impl );
 CK_DLL_SFUN( random2_impl );
 CK_DLL_SFUN( srandom_impl );
+CK_DLL_SFUN( randomize_impl );
 
 CK_DLL_SFUN( gauss_impl );
 
+CK_DLL_SFUN( cossim_impl );
+CK_DLL_SFUN( cossim3d_impl );
+CK_DLL_SFUN( cossim4d_impl );
+
+CK_DLL_SFUN( euclidean_impl );
+CK_DLL_SFUN( euclidean2d_impl );
+CK_DLL_SFUN( euclidean3d_impl );
+CK_DLL_SFUN( euclidean4d_impl );
+
+CK_DLL_SFUN( map_impl );
+CK_DLL_SFUN( map2_impl );
+
 
 
 
