@@ -358,7 +358,7 @@ public:
         // TODO
     }
 
-    // add OSC method, e.g,. "/foo/frequency"
+    // add OSC method, e.g., "/foo/frequency"
     void addMethod( const std::string & method, OscIn * obj )
     {
         // message to server
@@ -1584,7 +1584,7 @@ CK_DLL_MFUN( oscmsg_numArgs )
 
 CK_DLL_MFUN( oscmsg_getInt )
 {
-    int i = GET_NEXT_INT( ARGS );
+    t_CKINT i = GET_NEXT_INT( ARGS );
     Chuck_ArrayInt * args_obj = (Chuck_ArrayInt *)OBJ_MEMBER_OBJECT( SELF, oscmsg_offset_args );
     Chuck_Object * arg_obj;
 
@@ -1602,7 +1602,7 @@ CK_DLL_MFUN( oscmsg_getInt )
 
 CK_DLL_MFUN( oscmsg_getFloat )
 {
-    int i = GET_NEXT_INT( ARGS );
+    t_CKINT i = GET_NEXT_INT( ARGS );
     Chuck_ArrayInt * args_obj = (Chuck_ArrayInt *)OBJ_MEMBER_OBJECT( SELF, oscmsg_offset_args );
     Chuck_Object * arg_obj;
     if( i >= 0 && i < args_obj->size() )
@@ -1616,7 +1616,7 @@ CK_DLL_MFUN( oscmsg_getFloat )
 
 CK_DLL_MFUN( oscmsg_getString )
 {
-    int i = GET_NEXT_INT( ARGS );
+    t_CKINT i = GET_NEXT_INT( ARGS );
     Chuck_ArrayInt * args_obj = (Chuck_ArrayInt *)OBJ_MEMBER_OBJECT( SELF, oscmsg_offset_args );
     Chuck_Object * arg_obj;
 
