@@ -167,7 +167,7 @@ string toupper( const string & str )
 
 //-----------------------------------------------------------------------------
 // name: capitalize()
-// capitalize first character
+// desc: capiitalize first character
 //-----------------------------------------------------------------------------
 string capitalize( const string & s )
 {
@@ -183,6 +183,45 @@ string capitalize( const string & s )
 
 
 
+//-----------------------------------------------------------------------------
+// name: capitalize_and_periodize()
+// desc: capiitalize first character and ensure trailing period
+//-----------------------------------------------------------------------------
+string capitalize_and_periodize( const string & s )
+{
+    // copy
+    string retval = capitalize( trim(s) );
+    // check
+    if( retval.length() > 0 )
+    {
+        char c = retval[retval.length()-1];
+        // check for other punctuation
+        switch( c )
+        {
+            case '.':
+            case ',':
+            case '!':
+            case '?':
+            case ')':
+            case '(':
+            case '#':
+            case '\'':
+            case '\"':
+            case '\n':
+                break;
+
+            // in all other cases, append .
+            default:
+                retval += '.';
+        }
+    }
+    // done
+    return retval;
+}
+
+
+
+
 //-----------------------------------------------------------------------------
 // name: trim()
 // desc: return a whitespace (spaces and tabs)-trimmed string
