@@ -94,7 +94,7 @@ std::string ChuckAudio::m_dac_name = "";
 std::string ChuckAudio::m_adc_name = "";
 std::string ChuckAudio::m_driver_name = "";
 RtAudio * ChuckAudio::m_rtaudio = NULL;
-f_audio_cb ChuckAudio::m_audio_cb = NULL;
+ck_f_audio_cb ChuckAudio::m_audio_cb = NULL;
 void * ChuckAudio::m_cb_user_data = NULL;
 
 
@@ -271,10 +271,23 @@ void print( const RtAudio::DeviceInfo & info )
 // name: rtAudioErrorHandler()
 // desc: the RtAudio error handler
 //-----------------------------------------------------------------------------
-static void rtAudioErrorHandler( RtAudioErrorType t, const std::string & errorText)
+static void rtAudioErrorHandler( RtAudioErrorType t, const std::string & errorText )
 {
-    // problem finding audio devices, most likely
-    EM_error2( 0, "%s", errorText.c_str() );
+    // check if empty string
+    if( errorText.empty() ) return;
+
+    // check if warning or not a warning
+    if( t == RTAUDIO_WARNING )
+    {
+        // output to warning log level
+        EM_log( CK_LOG_WARNING, "%s", errorText.c_str() );
+    }
+    else
+    {
+        // output as error
+        EM_error2( 0, "%s", errorText.c_str() );
+        // NOTE: problem finding audio devices, likely
+    }
 }
 
 
@@ -736,7 +749,7 @@ t_CKBOOL ChuckAudio::initialize( t_CKUINT dac_device,
                                  t_CKUINT sample_rate,
                                  t_CKUINT buffer_size,
                                  t_CKUINT num_buffers,
-                                 f_audio_cb callback,
+                                 ck_f_audio_cb callback,
                                  void * data,
                                  t_CKBOOL force_srate,
                                  const char * driver )
@@ -788,7 +801,7 @@ t_CKBOOL ChuckAudio::initialize( t_CKUINT dac_device,
         // error reported above
         goto error; // to clean up
     }
-        
+
     // convert 1-based ordinal to 0-based ordinal (added 1.3.0.0)
     // note: this is to preserve previous devices numbering after RtAudio change
     if( m_num_channels_out > 0 )
@@ -1260,7 +1273,7 @@ t_CKBOOL ChuckAudio::stop( )
 // name: shutdown()
 // desc: ...
 //-----------------------------------------------------------------------------
-void ChuckAudio::shutdown()
+void ChuckAudio::shutdown( t_CKUINT msWait )
 {
     // check flag
     if( !m_init ) return;
@@ -1275,6 +1288,9 @@ void ChuckAudio::shutdown()
         // m_rtaudio->cancelStreamCallback();
         // m_rtaudio->stopStream();
         stop();
+
+        // wait for thread to wrap up | 1.5.1.3 (ge) added
+        if( msWait > 0 ) ck_usleep( msWait * 1000 );
     }
 
     // close stream
